/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BudgetPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy#custom_tags BudgetPolicy#custom_tags}
    */
    readonly customTags?: BudgetPolicyCustomTags[] | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy#policy_name BudgetPolicy#policy_name}
    */
    readonly policyName?: string;
}
export interface BudgetPolicyCustomTags {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy#key BudgetPolicy#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy#value BudgetPolicy#value}
    */
    readonly value?: string;
}
export declare function budgetPolicyCustomTagsToTerraform(struct?: BudgetPolicyCustomTags | cdktf.IResolvable): any;
export declare function budgetPolicyCustomTagsToHclTerraform(struct?: BudgetPolicyCustomTags | cdktf.IResolvable): any;
export declare class BudgetPolicyCustomTagsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): BudgetPolicyCustomTags | cdktf.IResolvable | undefined;
    set internalValue(value: BudgetPolicyCustomTags | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class BudgetPolicyCustomTagsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: BudgetPolicyCustomTags[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): BudgetPolicyCustomTagsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy databricks_budget_policy}
*/
export declare class BudgetPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_budget_policy";
    /**
    * Generates CDKTF code for importing a BudgetPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the BudgetPolicy to import
    * @param importFromId The id of the existing BudgetPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the BudgetPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.72.0/docs/resources/budget_policy databricks_budget_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BudgetPolicyConfig = {}
    */
    constructor(scope: Construct, id: string, config?: BudgetPolicyConfig);
    private _customTags;
    get customTags(): BudgetPolicyCustomTagsList;
    putCustomTags(value: BudgetPolicyCustomTags[] | cdktf.IResolvable): void;
    resetCustomTags(): void;
    get customTagsInput(): cdktf.IResolvable | BudgetPolicyCustomTags[] | undefined;
    get policyId(): string;
    private _policyName?;
    get policyName(): string;
    set policyName(value: string);
    resetPolicyName(): void;
    get policyNameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
